orchestra_flutter library
Classes
-
EntityNotifier<
TEntity extends Entity> -
A ValueNotifier that listens to changes in a specific
Entityand notifies listeners when it changes. -
EntityWatcher<
TEntity extends Entity> -
A widget that listens to changes in a
Entityand rebuilds when it changes. - MultiEntityNotifier
-
A ValueNotifier that listens to changes in multiple
Entitytypes and notifies listeners when any of them changes. - MultiEntityNotifierValue
- A helper class to access multiple entities from a MultiEntityNotifier value.
- MultiEntityWatcher
-
A widget that listens to changes in multiple
Entitytypes and rebuilds when any of them changes. - MultiEntityWatcherValue
- Helper class to expose multiple entities to the builder and listener of MultiEntityWatcher.
- OrchestraBuilder
- A widget that builds itself based on the orchestra context.
- OrchestraHandle
- Context for accessing orchestra from widgets.
- OrchestraScope
- A widget that provides an Orchestrator scope to its descendants.
-
OrchestraState<
TWidget extends OrchestraStatefulWidget> - OrchestraStatefulWidget
- Base class for stateful orchestra widgets.
- OrchestraWidget
- Base class for orchestra widgets.